@@ -191,17 +191,17 @@ def viperconsumefromtopic(vipertoken,host,port,topic,consumerid,companyname,part
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
+def viperhpdepredict(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,inputdata,enabletls=0,delay=0,hpdeport=-999,brokerhost='',brokerport=9092,
                      timeout=120,usedeploy=0,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
     
-    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
+    if (len(host)==0 or len(vipertoken)==0 or port==-999 or len(consumefrom)==0 or len(inputdata)==0 or len(produceto)==0 or len(companyname)==0 or len(consumerid)==0
                  or len(producerid)==0 or len(hpdehost)==0 or hpdeport==-999):
-         return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
+         return "Please enter host,port,vipertoken,consumefrom,inputdata,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdepredict?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&delay=" + str(delay) + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
+           "&delay=" + str(delay) + "&inputdata="+ inputdata + "&enabletls=" + str(enabletls) + "&producerid="+producerid + "&usedeploy=" +str(usedeploy) +"&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost + "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
@@ -222,7 +222,7 @@ def viperhpdeoptimize(vipertoken,host,port,consumefrom,produceto,companyname,con
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport=-999,offset=0,islogistic=0,
+def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,modelruns=50,hpdeport=-999,offset=0,islogistic=0,
                       brokerhost='',brokerport=9092,timeout=120,microserviceid=''):
 
     #reads the fieldnames and gets latest data from each stream (or fieldname)
@@ -232,7 +232,7 @@ def viperhpdetraining(vipertoken,host,port,consumefrom,produceto,companyname,con
          return "Please enter host,port,vipertoken,consumefrom,produceto,companyname,consumerid,producerid,hpdehost,hpdeport"
         
     value=("viperhpdetraining?vipertoken="+vipertoken + "&consumefrom="+consumefrom + "&produceto=" + produceto + "&consumerid="+consumerid +
-           "&producerid="+producerid + "&companyname="+companyname + "&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+
+           "&producerid="+producerid + "&companyname="+companyname + "&modelruns="+str(modelruns) +"&hpdehost=" +hpdehost +"&hpdeport="+str(hpdeport)+"&brokerhost="+brokerhost+
            "&brokerport="+str(brokerport))
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
@@ -261,13 +261,13 @@ def vipercreatetrainingdata(vipertoken,host,port,consumefrom,produceto,dependent
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
     return val
 
-def vipercreatetopic(vipertoken,host,port,topic,companyname,contactname,contactemail,location,description,brokerhost='',brokerport=-999,numpartitions=1,replication=1,microserviceid=''):
+def vipercreatetopic(vipertoken,host,port,topic,companyname,contactname,contactemail,location,description,enabletls=0,brokerhost='',brokerport=-999,numpartitions=1,replication=1,microserviceid=''):
 
     if len(host)==0 or len(vipertoken)==0 or port==-999 or len(topic)==0 or len(companyname)==0 or len(contactname)==0 or len(contactemail)==0 or len(location)==0 or len(description)==0:
          return "Please enter host,port,vipertoken,topic, companyname,contactname,contactemail,location and description"
         
     value=("createtopics?vipertoken="+vipertoken + "&topic="+topic + "&companyname=" + companyname + "&contactname="+contactname +
-           "&contactemail="+contactemail + "&location="+location+"&description="+description+"&numpartitions="+str(numpartitions)+
+           "&contactemail="+contactemail + "&location="+location+"&description="+description+ "&enabletls="+str(enabletls) + "&numpartitions="+str(numpartitions)+
            "&replicationfactor="+str(replication) + "&brokerhost="+brokerhost + "&brokerport=" + str(brokerport) )
     loop = asyncio.get_event_loop()
     val=loop.run_until_complete(tcp_echo_clientviper(value, loop,host,port,microserviceid))
